package Socket_IFC;

// ================================================================
// Copyright (c) Bluespec, Inc., 2007 All Rights Reserved

// ----------------
// Imports from BSV libs

import FIFO::*;
import GetPut::*;
import ClientServer::*;

// ----------------
// Requests across a socket

typedef enum { NOP, WR, RD } ReqOp
        deriving (Bits, Eq);

function Action display_ReqOp (ReqOp op);
   case (op)
      NOP : $write ("NOP");
      WR  : $write ("WR");
      RD  : $write ("RD");
   endcase
endfunction

typedef Bit#(10)  ReqInfo;
typedef Bit#(32)  ReqAddr;
typedef Bit#(32)  ReqData;

typedef struct {
  ReqOp                  reqOp;
  ReqInfo                reqInfo;
  ReqAddr                reqAddr;
  ReqData                reqData;
} Socket_Req
  deriving (Bits);

function Action display_Socket_Req (Socket_Req req);
   action
     $write ("Socket_Req{");
     display_ReqOp (req.reqOp);
     if (req.reqOp != NOP)
        $write (", %h, %h, %h}", req.reqInfo, req.reqAddr, req.reqData);
     $display ("}");
   endaction
endfunction

// ================================================================
// Socket Responses

typedef enum { NOP, OK } RespOp
        deriving (Bits, Eq);

function Action display_RespOp (RespOp op);
   case (op)
      NOP  : $write ("NOP");
      OK   : $write ("OK");
   endcase
endfunction

typedef Bit#(10)   RespInfo;
typedef Bit#(1)    RespAddr;
typedef Bit#(32)   RespData;

typedef struct {
  RespOp                 respOp;
  RespInfo               respInfo;
  RespAddr               respAddr;
  RespData               respData;
} Socket_Resp
  deriving (Eq, Bits);

function Action display_Socket_Resp (Socket_Resp resp);
   action
     $write ("Socket_Resp{");
     display_RespOp (resp.respOp);
     if (resp.respOp != NOP)
        $write (", %h, %h, %h", resp.respInfo, resp.respAddr, resp.respData);
     $display ("}");
   endaction
endfunction

// ================================================================
// Some convenient definitions

typedef Client #(Socket_Req, Socket_Resp)  Socket_master_ifc;
typedef Server #(Socket_Req, Socket_Resp)  Socket_slave_ifc;

function Socket_master_ifc
         fifos_to_master_ifc (FIFO#(Socket_Req)  reqs,
                              FIFO#(Socket_Resp) resps);
   return
      interface Client
         interface request  = fifoToGet (reqs);
         interface response = fifoToPut (resps);
      endinterface;
endfunction

function Socket_slave_ifc
         fifos_to_slave_ifc (FIFO#(Socket_Req) reqs,
                             FIFO#(Socket_Resp) resps);
   return
      interface Server
         interface request  = fifoToPut (reqs);
         interface response = fifoToGet (resps);
      endinterface;
endfunction

endpackage: Socket_IFC
