
################################################################################
### pick a technology to use (i.e. put the library at the front of the
### search path)
################################################################################

set search_path [concat [list  /tools/libraries/TSMC_CL018G_SC/aci/sc/synopsys/] $search_path]

### pick the library (usually slow, typical, fast)
set library_name "slow"
set target_library "$library_name.db"

### and also a wire load model
set wire_load_model_name "tsmc18_wl10"

################################################################################
### Put in one analyze line for every source .v file
################################################################################

analyze -f verilog mkDMA.v
analyze -f verilog mkFifo2.v
analyze -f verilog mkFifo4.v
elaborate mkDMA

current_design mkDMA

################################################################################
### Load the library and add a wire load model (if desired)
################################################################################

read_db "$library_name.db"

set_wire_load_model -name $wire_load_model_name -library $library_name

################################################################################
### Do the synthesis
################################################################################

set_max_area 0.0

set clock_period 3.5

set io_delay [expr 0.25 * $clock_period]

create_clock [get_ports CLK]  -period $clock_period

set_dont_touch_network CLK
set_input_delay  $io_delay -clock CLK [all_inputs]
set_output_delay $io_delay -clock CLK [all_outputs]

compile -ungroup_all -map_effort high
compile -ungroup_all -map_effort high

################################################################################
### Write out results
################################################################################

current_design mkDMA

report_timing -net -trans -max_paths 10 > timing.report

report_reference > mkDMA.ref
report_resources > mkDMA.resources
report_area      > mkDMA.area

write  -f verilog -o mkDMA.post_dc.v

################################################################################
### clean eveything out
################################################################################

#remove_design -all
